import requests
import json


class skingrabber:
    """This is the class for all skingrabber functions"""

    def __init__(self):
        self.url = "https://api.mojang.com/users/profiles/minecraft/"

    def get_uuid(self, user):
        """user is the nickname of the player in this case"""

        response = requests.get(self.url + user)
        if response.status_code != 200:
            return None
        else:
            responsejson = json.loads(response.content)

            uuid = responsejson["id"]
            return uuid

    def get_skin(self, user):
        """The 2D version of the users skin"""

        response = requests.get(self.url + user)
        if response.status_code != 200:
            return None
        else:
            responsejson = json.loads(response.content)

            uuid = responsejson["id"]
            return f"https://crafatar.com/skins/{uuid}"

    def get_skin_rendered(self, user):
        """The 3D rendered version of the users skin"""

        response = requests.get(self.url + user)
        if response.status_code != 200:
            return None
        else:
            responsejson = json.loads(response.content)

            uuid = responsejson["id"]
            return f"https://crafatar.com/renders/body/{uuid}"



import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="skingrabber",
    version="0.1.4",
    author="MakufonSkifto",
    author_email="emirsurmen@gmail.com",
    license="MIT",
    description="A Python 3 wrapper for the Minecraft Skin API",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/MakufonSkifto/skingrabber",
    packages=setuptools.find_packages(),
    install_requires=["requests"],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
    ],
    python_requires='>=3.6',
)
